pitchtools.calculate_melodic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch
========================================================================================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch.calculate_melodic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch
